@@ -1,23 +1,33 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0">
+<TS version="2.1" language="sk">
 <context>
     <name>SpacerConfiguration</name>
     <message>
-        <location filename="../spacerconfiguration.ui" line="12"/>
+        <location filename="../spacerconfiguration.ui" line="14"/>
         <source>Spacer Settings</source>
         <translation>Nastavenia medzery</translation>
     </message>
     <message>
-        <location filename="../spacerconfiguration.ui" line="18"/>
+        <location filename="../spacerconfiguration.ui" line="20"/>
         <source>Space width:</source>
         <translation>Šírka medzery:</translation>
     </message>
     <message>
-        <location filename="../spacerconfiguration.ui" line="38"/>
+        <location filename="../spacerconfiguration.ui" line="40"/>
         <source>Space type:</source>
         <translation>Typ medzery:</translation>
     </message>
+    <message>
+        <location filename="../spacerconfiguration.ui" line="57"/>
+        <source>fixed</source>
+        <translation>Pevný</translation>
+    </message>
+    <message>
+        <location filename="../spacerconfiguration.ui" line="71"/>
+        <source>expandable</source>
+        <translation>Rozšiřitelný</translation>
+    </message>
     <message>
         <location filename="../spacerconfiguration.cpp" line="34"/>
         <source>lined</source>
